#!usr/bin/env python
# -*- coding: utf8 -*-

import os
import re
import pandas as pd
from pprint import pprint
from pympi.Praat import TextGrid

from utils import text_read, text_dump, walk_dir, extract_source_sentence_file, SENT_ID_PATTERN


def annotate_textgrids(path):
    all_textgrids = walk_dir(path, ext='.TextGrid')

    for textgrid_file in all_textgrids:
        tg_path, tg_filename = os.path.split(textgrid_file)
        dir_name = tg_path.split(os.sep)[-1]

        # Read TextGrid files
        textgrid = TextGrid(textgrid_file)
        tier_list = [n for _, n in list(textgrid.get_tier_name_num())]

        assert "key-syll-segment-sound" in tier_list, ValueError('Target tier not found.')
        assert "key-sound-subsegments" not in tier_list, ValueError('Target tier exists already!')

        # Read transcription interval
        trans_tier = textgrid.get_tier('key-syll-segment-sound')
        subsegment_tier = textgrid.add_tier('key-sound-subsegments')

        for tg_start, tg_end, tg_trans in trans_tier.get_all_intervals():
            subsegment_tier.add_interval(tg_start, tg_end, tg_trans)

        ordered_tiers = [textgrid.get_tier('transcription'),
                         textgrid.get_tier('key-word'),
                         textgrid.get_tier('key-syll-segment'),
                         textgrid.get_tier('key-syll-segment-sound'),
                         textgrid.get_tier('key-sound-subsegments')]
        textgrid.tiers = list(reversed(ordered_tiers))
        textgrid.to_file(textgrid_file)


def main(**kwargs):
    annotate_textgrids(**kwargs)


def _parse_args(argv):
    import argparse

    parser = argparse.ArgumentParser(description='Add key-sound-subsegments tier if it does not exist.')
    parser.add_argument('--path', required=True,
                        help='Path to the directory whose file will be annotated.')
    args = parser.parse_args(argv)

    return vars(args)


if __name__ == '__main__':
    import sys
    import logging

    pgrm_name, argv = sys.argv[0], sys.argv[1:]
    args = _parse_args(argv)

    try:
        main(**args)
        sys.exit(0)
    except Exception as e:
        logging.exception(e)
        sys.exit(1)