#!usr/bin/env python
# -*- coding: utf8 -*-


import os
import re
from pprint import pprint
from pympi.Praat import TextGrid
from itertools import chain
import unicodedata
from natsort import natsorted
from utils import walk_dir, CustomEnum, Enum


tier_names = [('trans', 'transcription'),
              ('keyword', 'key-word'),
              ('keysyll', 'key-syll-segment'),
              ('keysound', 'key-syll-segment-sound'),
              ('keysubs', 'key-sound-subsegments')]

TIER = Enum('TIER', tier_names, type=CustomEnum)

def unormalise(string):
    return unicodedata.normalize('NFC', unicodedata.normalize("NFKD", string))

def check_textgrids(path):
    all_textgrids = walk_dir(path, ext='.TextGrid')

    for textgrid_file in natsorted(all_textgrids):
        _, tg_fn = os.path.split(textgrid_file)
        textgrid = TextGrid(textgrid_file)

        key_tier_annotated = len(list(textgrid.get_tier(TIER.keysyll).get_intervals())) >= 3
        if not key_tier_annotated: continue

        words = [(start, stop, value.replace('[', '').replace(']', ''))
                for (start, stop, value) in textgrid.get_tier(TIER.keyword).get_intervals() if '[' in value]
        syls = [item for item in textgrid.get_tier(TIER.keysyll).get_intervals()]
        sounds = [item for item in textgrid.get_tier(TIER.keysound).get_intervals()]

        for word in words:
            word_start, word_end, word_value = word
            word_value = word_value.replace('[', '').replace(']', '')

            target_syls = [(syl_start, syl_end, syl_val) for (syl_start, syl_end, syl_val) in syls
                           if syl_start >= word_start and syl_end <= word_end]
            target_sounds = [(syl_start, syl_end, syl_val) for (syl_start, syl_end, syl_val) in sounds
                           if syl_start >= word_start and syl_end <= word_end]

            syl_realisation = ''.join([p for (_, _, p) in target_syls])
            syl_realisation = syl_realisation.replace('clos', '').replace('rel', '')

            sound_realisation = ''.join([p for (_, _, p) in target_sounds])
            sound_realisation = sound_realisation.replace('clos', '').replace('rel', '')

            syl_realisation = unormalise(syl_realisation)
            sound_realisation = unormalise(sound_realisation)
            word_value = unormalise(word_value)

            if syl_realisation != word_value:
                print("")
                print('{}: SYL [{}] != [{}]'.format(tg_fn, syl_realisation, word_value))
                print(' '.join(["{} -> {}".format(i, j) for (i, j) in zip(syl_realisation, word_value) if i!=j]))

            if sound_realisation != word_value:
                print('\t{}: SOUND [{}] != [{}]'.format(tg_fn, sound_realisation, word_value))
                print(' '.join(["{} -> {}".format(i, j) for (i, j) in zip(sound_realisation, word_value) if i!=j]))


def main(**kwargs):
    check_textgrids(**kwargs)


def _parse_args(argv):
    import argparse

    parser = argparse.ArgumentParser(description='Check that the annotations in each tier is coherent w.r.t. to the '
                                                 '"parent" tier (e.g. no missing sound, no missing, letter, etc.).')
    parser.add_argument('--path', required=True,
                        help='Path to the directory containing the TextGrid files.')
    args = parser.parse_args(argv)

    return vars(args)


if __name__ == '__main__':
    import sys
    import logging

    pgrm_name, argv = sys.argv[0], sys.argv[1:]
    args = _parse_args(argv)

    try:
        main(**args)
        sys.exit(0)
    except Exception as e:
        logging.exception(e)
        sys.exit(1)