#!usr/bin/env python
# -*- coding: utf8 -*-

import os
from pprint import pprint
from natsort import natsorted
import xlsxwriter
import shutil
from itertools import chain
from identify_minimal_syllable import strip_accents
from utils import text_read, text_dump, walk_dir, \
    extract_source_sentence_file, get_tg_metadata, get_summary_data, find_all

class reversor:
    def __init__(self, obj):
        self.obj = obj

    def __eq__(self, other):
        return other == self.obj

    def __lt__(self, other):
           return other < self.obj


def sorting_key(s):
    print(s)
    parts = os.path.basename(s).split('_')
    sent_id = parts[1].split('.')
    return sent_id[0], parts[-1], reversor(sent_id[2]), sent_id[1] # pair ID, speaker, word, sent


def to_excel(contrasts):
    # Dump to Excel file
    workbook = xlsxwriter.Workbook('laac-lscp-annotations-raw-carrier.xlsx')
    for constrast_key, constrast_tgt in sorted(contrasts.items(), key=lambda tup:tup[0]):
        worksheet = workbook.add_worksheet(name=constrast_key)

        worksheet.write(0, 0, "filename")
        worksheet.write(0, 1, "status")
        skipped=0
        common_pref = os.path.commonpath(constrast_tgt)

        for i_tgt, tgt_fn in enumerate(natsorted(constrast_tgt, key=sorting_key, reverse=False), 1):
            tgt_file_path, tgt_file_name = os.path.split(tgt_fn)
            final_tgt_file_name = 'ann-{}_{}'.format(str(i_tgt).zfill(3), tgt_file_name)
            final_tgt_path = os.path.join(tgt_file_path, final_tgt_file_name)

            worksheet.write(i_tgt-skipped, 0, final_tgt_path.replace(common_pref+"/", ''))
            worksheet.write(i_tgt-skipped, 1, "")
    workbook.close()


def to_dir(to, contrasts):
    if not os.path.exists(to):
        raise ValueError('{} is not a valid path!'.format(to))

    common_pref = os.path.commonpath(list(chain(*contrasts.values())))

    for constrast_key, constrast_tgt in sorted(contrasts.items(), key=lambda tup: tup[0]):

        to_path = os.path.join(to, 'contrast-{}'.format(constrast_key))
        os.makedirs(to_path, exist_ok=True)
        for i_tgt, tgt_fn in enumerate(natsorted(constrast_tgt, key=sorting_key, reverse=False), 1):
            tgt_file_path, tgt_file_name = os.path.split(tgt_fn)
            final_tgt_file_name = 'ann-{}_{}'.format(str(i_tgt).zfill(3), tgt_file_name)

            wav_path = (tgt_fn
                   .replace(common_pref, "recordings/raw")
                   .replace('.TextGrid', '.wav')
                   .replace('/line', "/wavs/line"))
            wav_file_path, wav_file_name = os.path.split(wav_path)
            final_wav_file_name = 'ann-{}_{}'.format(str(i_tgt).zfill(3), wav_file_name)

            # print(tgt_fn, os.path.join(to_path, final_tgt_file_name))
            shutil.copy2(tgt_fn, os.path.join(to_path, final_tgt_file_name))
            # print(wav_path, os.path.join(to_path, final_wav_file_name))
            shutil.copy2(wav_path, os.path.join(to_path, final_wav_file_name))


def get_textgrids_targets(path, to):
    all_textgrids = walk_dir(path, ext='.TextGrid')

    contrasts = {}

    for textgrid_file in all_textgrids:
        tg_path, tg_filename = os.path.split(textgrid_file)
        dir_name = tg_path.split(os.sep)[-1]

        # Get metadata (apply twice if respeak session)
        target_sentence_file = extract_source_sentence_file(dir_name)
        if 'respeak' in textgrid_file:
            continue
            target_sentence_file = extract_source_sentence_file(target_sentence_file)

        # Get sentid, wordid, senttype
        pair_id, word_id, sent_type = get_tg_metadata(tg_filename)

        target_summary_sent, target_summary_word, target_summary_syl = \
            get_summary_data(target_sentence_file, pair_id, word_id, sent_type)
        target_summary_syl = strip_accents(target_summary_syl)
        found_glottals = find_all(target_summary_syl, "'")

        target_sounds = [target_summary_syl[idx-1] for idx in found_glottals]
        for target_sound in target_sounds:
            contrasts.setdefault(target_sound, [])
            contrasts[target_sound].append(textgrid_file)

    to_excel(contrasts)
    if to:
        to_dir(to, contrasts)

def main(**kwargs):
    get_textgrids_targets(**kwargs)


def _parse_args(argv):
    import argparse

    parser = argparse.ArgumentParser(description='Generates an Excel file with several sheets where each sheet contains '
                                                 'the list of files for a given glottal/non-glottal opposition. If '
                                                 '--to is specified, then several directories (one per constrast) will '
                                                 'be created in the --to directory where each TextGrid will be copied '
                                                 'along with its WAV file.'
                                     )
    parser.add_argument('--path', required=True,
                        help='Path to the directory whose file will be annotated.')
    parser.add_argument('--to', required=False, default=False,
                        help='Prepare annotation campaign by copying all the file to the specified directory.'
                             'Files will be store in separate folders.')
    args = parser.parse_args(argv)

    return vars(args)


if __name__ == '__main__':
    import sys
    import logging

    pgrm_name, argv = sys.argv[0], sys.argv[1:]
    args = _parse_args(argv)

    try:
        main(**args)
        sys.exit(0)
    except Exception as e:
        logging.exception(e)
        sys.exit(1)