#!usr/bin/env python
# -*- coding: utf8 -*-

import os
import re
from pprint import pprint
from pympi.Praat import TextGrid
from itertools import chain

from utils import walk_dir, CustomEnum, Enum

tier_names = [('trans', 'transcription'),
              ('keyword', 'key-word'),
              ('keysyll', 'key-syll-segment'),
              ('keysound', 'key-syll-segment-sound'),
              ('keysubs', 'key-sound-subsegments')]

replace_phon = {
    '\\~v': "̰",
    '\\:v': "̤",
    '\\?g': 'ʔ',
    '\\^h': 'ʰ',
    '\\~^': '̃',
}

TIER = Enum('TIER', tier_names, type=CustomEnum)

def handle_annotations():
    textgrid_files = walk_dir('./annotations/textgrid/LAAC-LSCP/WNH/raw', ext='.TextGrid', return_full_path=True)

    all_syls = 0

    realisations = dict()

    for textgrid_file in textgrid_files:
        textgrid = TextGrid(textgrid_file)

        key_tier_annotated = len(list(textgrid.get_tier(TIER.keysyll).get_intervals())) >= 3
        if not key_tier_annotated: continue

        # target_word = [(start, stop, value) for (start, stop, value) in
        #                textgrid.get_tier(TIER.keyword).get_intervals() if '[' in value]
        # target_syls = list(chain(*[re.findall('\[(.*?)\]', tgw) for (_,_,tgw) in target_word]))
        target_syls = [(start, stop, value) for (start, stop, value) in
                          textgrid.get_tier(TIER.keysyll).get_intervals() if value not in ['clos', 'rel']]

        for target_syl in target_syls:
            syl_start, syl_end, syl_val = target_syl
            if syl_val.strip() == '': continue

            realisation = [(phon_start, phon_end, phon_val) for (phon_start, phon_end, phon_val) in
                           textgrid.get_tier(TIER.keysubs).get_intervals()
                           if phon_start >= syl_start and phon_end <= syl_end]

            realisations.setdefault(syl_val, [])

            phon_realisation = ''.join([p for (_,_,p) in realisation])
            for k, v in replace_phon.items():
                phon_realisation = phon_realisation.replace(k, v)

            realisations[syl_val].append(phon_realisation)

            all_syls +=1

    pprint(realisations)
    print(all_syls)


def main():
    # Print all the realisation of a given keysyll
    handle_annotations()

if __name__ == '__main__':
    main()