#!usr/bin/env python
# -*- coding: utf8 -*-

import os
from pprint import pprint
import shutil

from utils import text_read, text_dump, walk_dir


def move_files(ext, src, dst, apply):
    files = walk_dir(src, ext=ext)
    for file in files:
        # Get file metadata
        file_path, file_filename = os.path.split(file)

        common_pref = os.path.commonprefix([src, file_path])
        print(common_pref)
        target_filepath = file_path.replace(common_pref, dst)

        if apply:
            os.makedirs(target_filepath, exist_ok=True)
            shutil.move(file, target_filepath)
        else:
            print(file_path, target_filepath)


def main(**kwargs):
    move_files(**kwargs)


def _parse_args(argv):
    import argparse

    parser = argparse.ArgumentParser(description='Move a bunch of files while preserving directory structure.')
    parser.add_argument('--ext', required=True, help='Extension of the files to be moved.')
    parser.add_argument('--src', required=True, help='Source directory.')
    parser.add_argument('--dst', required=True, help='Destination directory.')
    parser.add_argument('--apply', required=False, action='store_true', default=False)
    args = parser.parse_args(argv)

    return vars(args)


if __name__ == '__main__':
    import sys
    import logging

    pgrm_name, argv = sys.argv[0], sys.argv[1:]
    args = _parse_args(argv)

    try:
        main(**args)
        sys.exit(0)
    except Exception as e:
        logging.exception(e)
        sys.exit(1)
