#!usr/bin/env python
# -*- coding: utf8 -*-
#
# -----------------------------------------------------------------------------
#   File: utils.py (as part of project TSIMANE-GLOTTAL)
#   Created: 11/01/2023 10:03
#   Last Modified: 11/01/2023 10:03
# -----------------------------------------------------------------------------
#   Author: William N. Havard
#           Postdoctoral Researcher
#
#   Mail  : william.havard@ens.fr / william.havard@gmail.com
#  
#   Institution: ENS / Laboratoire de Sciences Cognitives et Psycholinguistique
#
# ------------------------------------------------------------------------------
#   Description: 
#       • 
# -----------------------------------------------------------------------------
import os
import unicodedata
from enum import Enum, auto, unique

@unique
class TokTyp(Enum):
    TYPE = 'type'
    TOKEN = 'token'

    @classmethod
    def __from(cls, label, attr):
        for tasks_const in list(cls):
            if getattr(tasks_const, attr) == label:
                return tasks_const
        raise ValueError('Unknown task {}!'.format(label))

    @classmethod
    def from_value(cls, label):
        return cls.__from(label, 'value')

    @classmethod
    def from_name(cls, label):
        return cls.__from(label, 'name')

    @classmethod
    def values(cls):
        return (getattr(o, 'value') for o in list(cls))

    @classmethod
    def names(cls):
        return (getattr(o, 'name') for o in list(cls))

    @classmethod
    def keys(cls):
        return cls.names()

    def __eq__(self, other):
        if type(other) == str:
            return other == self.name or other == self.value
        return super().__eq__(other)


def text_read(txt_path, strip=True):
    with open(txt_path, 'r') as in_file:
        lines = in_file.readlines()
        if strip:
            lines = map(str.strip, lines)
    return lines


def walk_dir(path, ext='', return_full_path=True):
    files = []
    for p, d, f in os.walk(path):
        for ff in f:
            if ff.endswith(ext):
                path_suffix = p.replace(os.path.commonprefix([path, p]), '').lstrip(os.sep)
                if return_full_path:
                    files.append(os.path.join(path, path_suffix, ff))
                else:
                    files.append(os.path.join(path_suffix, ff))
    return sorted(files)


def ulen(ustring):
    return len(list(uiter(ustring)))


def ngram_iterator(ulist, n):
    for i in range(len(ulist) - n + 1):
        yield ulist[i:i+n]


def uiter(ustring):
    end = len(ustring)-1
    i_char = 0
    while i_char <= end:
        end_char = i_char + 1
        while end_char <= end and unicodedata.category(ustring[end_char]) == 'Mn':
            end_char += 1
        yield ustring[i_char:end_char]
        i_char = end_char
